@@ -1,10 +1,9 @@
-__version__ = '0.0.16'
+__version__ = '0.0.17'
 
 import evaics.sdk as sdk
 from types import SimpleNamespace
 import psrt
 import threading
-import msgpack
 import time
 import os
 import uuid
@@ -20,6 +19,8 @@ except:
 from functools import partial
 from cachetools import TTLCache
 
+from evaics.sdk import pack, unpack
+
 encrypt = partial(pyaltt2.crypto.encrypt, hmac_key=True, b64=False)
 decrypt = partial(pyaltt2.crypto.decrypt, hmac_key=True, b64=False)
 
@@ -34,12 +35,10 @@ def get_key_val(key_id):
     try:
         return key_cache[key_id]
     except KeyError:
-        key = msgpack.loads(_d.service.rpc.call(
-            _d.key_svc,
-            elbus.rpc.Request('key.get',
-                              msgpack.dumps({'i': key_id
-                                            }))).wait_completed().get_payload(),
-                            raw=False)['key']
+        key = unpack(
+            _d.service.rpc.call(
+                _d.key_svc, elbus.rpc.Request('key.get', pack(
+                    {'i': key_id}))).wait_completed().get_payload())['key']
         key_cache[key_id] = key
         return key
 
@@ -50,7 +49,7 @@ def mark_node(node, status, info=None):
         payload['info'] = info
     _d.service.bus.send(
         f'RPL/NODE/{node}',
-        elbus.client.Frame(msgpack.dumps(payload), tp=elbus.client.OP_PUBLISH))
+        elbus.client.Frame(pack(payload), tp=elbus.client.OP_PUBLISH))
 
 
 def jreq(id, method, params=None):
@@ -138,7 +137,7 @@ class LegacyNode:
         rid = uuid.uuid4().bytes
         request_id = rid.hex()
         header = b'\x00\x03'
-        data = rid + zlib.compress(msgpack.dumps(payload))
+        data = rid + zlib.compress(pack(payload))
         cb = Callback()
         send_api_request(
             request_id, controller_id, header + self.key_ln.encode() + b'\x00' +
@@ -150,7 +149,7 @@ class LegacyNode:
             if cb.code != 200:
                 raise RuntimeError(
                     f'{controller_id} response error code: {cb.code}')
-            content = msgpack.loads(
+            content = unpack(
                 zlib.decompress(decrypt(cb.body, private_key,
                                         key_is_hash=True)))
             try:
@@ -292,8 +291,7 @@ class LegacyNode:
                     inventory.append(v4lmacro)
             _d.service.bus.send(
                 f'RPL/INVENTORY/{self.id}',
-                elbus.client.Frame(msgpack.dumps(inventory),
-                                   tp=elbus.client.OP_PUBLISH))
+                elbus.client.Frame(pack(inventory), tp=elbus.client.OP_PUBLISH))
             self.online = True
             mark_node(self.id,
                       'online',
@@ -314,8 +312,7 @@ def process_message(client, userdata, message):
         _d.test_passed.set()
     elif topic in _d.bulks:
         if message.payload.startswith(b'\x00'):
-            payload = msgpack.loads(zlib.decompress(message.payload[2:]),
-                                    raw=False)
+            payload = unpack(zlib.decompress(message.payload[2:]))
         else:
             payload = json.loads(message.payload.decode())
         node_id = payload['c'].split('/')[1]
@@ -332,8 +329,7 @@ def process_message(client, userdata, message):
                     'nstatus'] and state['value'] == state['nvalue'] else 1
             _d.service.bus.send(
                 f'RPL/ST/{state["oid"].replace(":", "/",1)}',
-                elbus.client.Frame(msgpack.dumps(v4state),
-                                   tp=elbus.client.OP_PUBLISH))
+                elbus.client.Frame(pack(v4state), tp=elbus.client.OP_PUBLISH))
     elif topic == 'controller/discovery':
         node_id = message.payload.decode().split('/')[1]
         try:
@@ -370,12 +366,12 @@ def handle_rpc(event):
     if method == 'node.list':
         if event.get_payload():
             raise elbus.rpc.RpcException(code=sdk.ERR_CODE_INVALID_PARAMS)
-        return msgpack.dumps(
+        return pack(
             sorted([c.serialize() for _, c in _d.lc.items()],
                    key=lambda k: k['id']))
     elif method == 'node.reload':
         try:
-            params = msgpack.loads(event.get_payload(), raw=False)
+            params = unpack(event.get_payload())
             node_id = params['i']
         except Exception as e:
             raise elbus.rpc.RpcException(str(e), sdk.ERR_CODE_INVALID_PARAMS)
@@ -388,7 +384,7 @@ def handle_rpc(event):
     # end of user method, the next methods are proxied to v3 nodes
     elif method.startswith('lvar.'):
         try:
-            params = msgpack.loads(event.get_payload(), raw=False)
+            params = unpack(event.get_payload())
             oid = params['i']
             node_id = params['node']
             p = {'i': oid}
@@ -407,10 +403,10 @@ def handle_rpc(event):
             raise elbus.rpc.RpcException(str(e), sdk.ERR_CODE_INVALID_PARAMS)
         node = _d.lc[node_id]
         node.call('lm', rm, p)
-        return msgpack.dumps(None)
+        return pack(None)
     elif method == 'action':
         try:
-            params = msgpack.loads(event.get_payload(), raw=False)
+            params = unpack(event.get_payload())
             node_id = params['node']
             i = params['i']
             priority = params['priority']
@@ -427,10 +423,10 @@ def handle_rpc(event):
             raise elbus.rpc.RpcException(str(e), sdk.ERR_CODE_INVALID_PARAMS)
         node = _d.lc[node_id]
         act_info = node.call('uc', 'action', p)
-        return msgpack.dumps(to_v4action(act_info, node_id))
+        return pack(to_v4action(act_info, node_id))
     elif method == 'action.result':
         try:
-            params = msgpack.loads(event.get_payload(), raw=False)
+            params = unpack(event.get_payload())
             node_id = params['node']
             i = params['i']
             u = uuid.UUID(bytes=params['u'])
@@ -439,10 +435,10 @@ def handle_rpc(event):
             raise elbus.rpc.RpcException(str(e), sdk.ERR_CODE_INVALID_PARAMS)
         node = _d.lc[node_id]
         act_info = node.call(ctp, 'result', {'u': str(u)})
-        return msgpack.dumps(to_v4action(act_info, node_id))
+        return pack(to_v4action(act_info, node_id))
     elif method == 'run':
         try:
-            params = msgpack.loads(event.get_payload(), raw=False)
+            params = unpack(event.get_payload())
             node_id = params['node']
             i = params['i']
             priority = params['priority']
@@ -458,7 +454,7 @@ def handle_rpc(event):
             raise elbus.rpc.RpcException(str(e), sdk.ERR_CODE_INVALID_PARAMS)
         node = _d.lc[node_id]
         act_info = node.call('lm', 'run', p)
-        return msgpack.dumps(to_v4action(act_info, node_id))
+        return pack(to_v4action(act_info, node_id))
     else:
         sdk.no_rpc_method()
 
